@@ -3,6 +3,7 @@ import os
 import boto3
 from botocore.exceptions import ClientError
 
+
 def define_feature_group(
     name,
     description,
@@ -20,7 +21,7 @@ def define_feature_group(
     environment_prefix=None,
 ):
     """
-    Primary function to call when defining a new feature group in a Jupyter notebook or script. This function is designed to succeed regardless of 
+    Primary function to call when defining a new feature group in a Jupyter notebook or script. This function is designed to succeed regardless of
     existing state of the system.
     """
     environment_prefix_name = environment_prefix
@@ -47,42 +48,44 @@ def define_feature_group(
         region_name=region_name,
     )
 
-
     feature_group_name = f"{environment_prefix_name}{name}"
-    feature_group_name = feature_group_name.replace('_', '-')
+    feature_group_name = feature_group_name.replace("_", "-")
 
     is_different = False
     is_new = is_feature_group_new(sagemakerclient, feature_group_name)
     if not is_new:
         is_different = is_feature_group_different(
-            sagemakerclient
-            ,feature_group_name
-            ,record_identifier_feature
-            ,event_time_feature
-            ,feature_definitions
-            ,online_store_config
-            ,offline_store_config
-            ,role_arn
-            ,description
+            sagemakerclient,
+            feature_group_name,
+            record_identifier_feature,
+            event_time_feature,
+            feature_definitions,
+            online_store_config,
+            offline_store_config,
+            role_arn,
+            description,
         )
 
     if is_different:
-        sagemakerclient.delete_feature_group(
-            FeatureGroupName=feature_group_name
+        sagemakerclient.delete_feature_group(FeatureGroupName=feature_group_name)
+
+    response = { 
+        "Message": "Feature group already exists with the provided definition."
+    }
+
+    if is_different or is_new:
+        response = sagemakerclient.create_feature_group(
+            FeatureGroupName=feature_group_name,
+            RecordIdentifierFeatureName=record_identifier_feature,
+            EventTimeFeatureName=event_time_feature,
+            FeatureDefinitions=feature_definitions,
+            OnlineStoreConfig=online_store_config,
+            OfflineStoreConfig=offline_store_config,
+            RoleArn=role_arn,
+            Description=description,
         )
 
-    response = sagemakerclient.create_feature_group(
-        FeatureGroupName=feature_group_name,
-        RecordIdentifierFeatureName=record_identifier_feature,
-        EventTimeFeatureName=event_time_feature,
-        FeatureDefinitions=feature_definitions,
-        OnlineStoreConfig=online_store_config,
-        OfflineStoreConfig=offline_store_config,
-        RoleArn=role_arn,
-        Description=description
-    )
-
-    return {"feature_group": response }
+    return {"feature_group": response}
 
 
 def is_feature_group_new(sagemakerclient, feature_group_name):
@@ -94,31 +97,30 @@ def is_feature_group_new(sagemakerclient, feature_group_name):
     except ClientError as e:
         return True
 
+
 def is_feature_group_different(
-    sagemakerclient
-    ,feature_group_name
-    ,record_identifier_feature
-    ,event_time_feature
-    ,feature_definitions
-    ,online_store_config
-    ,offline_store_config
-    ,role_arn
-    ,description
-): 
+    sagemakerclient,
+    feature_group_name,
+    record_identifier_feature,
+    event_time_feature,
+    feature_definitions,
+    online_store_config,
+    offline_store_config,
+    role_arn,
+    description,
+):
 
     response = sagemakerclient.describe_feature_group(
         FeatureGroupName=feature_group_name
     )
 
-    return response['RoleArn'] != role_arn or \
-        response['RecordIdentifierFeatureName'] != record_identifier_feature or \
-        response['EventTimeFeatureName'] != event_time_feature or \
-        response['FeatureDefinitions'] != feature_definitions or \
-        response['FeatureDefinitions'] != feature_definitions or \
-        response['OnlineStoreConfig'] != online_store_config or \
-        response['OfflineStoreCOnfig'] != offline_store_config or \
-        response['Description'] != description
-
-
-
-
+    return (
+        response["RoleArn"] != role_arn
+        or response["RecordIdentifierFeatureName"] != record_identifier_feature
+        or response["EventTimeFeatureName"] != event_time_feature
+        or response["FeatureDefinitions"] != feature_definitions
+        or response["FeatureDefinitions"] != feature_definitions
+        or response["OnlineStoreConfig"] != online_store_config
+        or response["OfflineStoreCOnfig"] != offline_store_config
+        or response["Description"] != description
+    )
